==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GetTransactionPDF.java <==
package com.example.model;

/**
 * Model for Get Transaction as JSON
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "GetTransactionPDF", description = "Model for Get Transaction as JSON")
@javax.xml.bind.annotation.XmlRootElement(name = "GetTransactionPDF")
public class GetTransactionPDF implements java.io.Serializable, com.example.model.Get200Response {

	private static final long serialVersionUID = 1L;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String flowType = null;
	private java.lang.String status = null;
	private java.lang.String transactionId = null;
	
	/**
	 */
	public GetTransactionPDF createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	@javax.validation.constraints.NotNull
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public GetTransactionPDF flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 */
	public GetTransactionPDF status(java.lang.String status) {
		setStatus(status);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("status")
	public java.lang.String getStatus() {
		return this.status;
	}
	public void setStatus(java.lang.String status) {
		this.status = status;
	}
	
	/**
	 */
	public GetTransactionPDF transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GetTransactionPDF getTransactionPDF = (GetTransactionPDF) o;
		return java.util.Objects.equals(this.createdAt, getTransactionPDF.createdAt)
				&& java.util.Objects.equals(this.flowType, getTransactionPDF.flowType)
				&& java.util.Objects.equals(this.status, getTransactionPDF.status)
				&& java.util.Objects.equals(this.transactionId, getTransactionPDF.transactionId);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.createdAt, this.flowType, this.status, this.transactionId);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GetTransactionPDF {\n");
		
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    status: ").append(toIndentedString(this.status)).append("\n");
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GetTransactionPDF.java <==
package com.example.model;

/**
 * Model for Get Transaction as JSON
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "GetTransactionPDF", description = "Model for Get Transaction as JSON")
@javax.xml.bind.annotation.XmlRootElement(name = "GetTransactionPDF")
public class GetTransactionPDF implements java.io.Serializable, com.example.model.Get200Response {

	private static final long serialVersionUID = 1L;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String flowType = null;
	private java.lang.String status = null;
	private java.lang.String transactionId = null;
	
	/**
	 */
	public GetTransactionPDF createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "created_at")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	@javax.validation.constraints.NotNull
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public GetTransactionPDF flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "flow_type")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 */
	public GetTransactionPDF status(java.lang.String status) {
		setStatus(status);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "status")
	@com.fasterxml.jackson.annotation.JsonProperty("status")
	public java.lang.String getStatus() {
		return this.status;
	}
	public void setStatus(java.lang.String status) {
		this.status = status;
	}
	
	/**
	 */
	public GetTransactionPDF transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "transaction_id")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GetTransactionPDF getTransactionPDF = (GetTransactionPDF) o;
		return java.util.Objects.equals(this.createdAt, getTransactionPDF.createdAt)
				&& java.util.Objects.equals(this.flowType, getTransactionPDF.flowType)
				&& java.util.Objects.equals(this.status, getTransactionPDF.status)
				&& java.util.Objects.equals(this.transactionId, getTransactionPDF.transactionId);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.createdAt, this.flowType, this.status, this.transactionId);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GetTransactionPDF {\n");
		
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    status: ").append(toIndentedString(this.status)).append("\n");
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
